@@ -1,4 +1,5 @@
 import json
+from json import JSONDecodeError
 
 from edupage_api.exceptions import BadCredentialsException
 from edupage_api.module import Module
@@ -36,12 +37,11 @@ class Login(Module):
 
         request_url = "https://portal.edupage.org/index.php?jwid=jw2&module=login"
         response = self.edupage.session.post(request_url, params=parameters)
-
-        if "wrongPassword" in response.url:
-            raise BadCredentialsException()
-
         data = response.content.decode()
 
+        if "wrongPassword" in response.url or "errorbox" in data:
+            raise BadCredentialsException()
+
         self.__parse_login_data(data)
         self.edupage.subdomain = data.split("-->")[0].split(" ")[-1]
 
@@ -78,3 +78,16 @@ class Login(Module):
 
         self.__parse_login_data(response.content.decode())
         self.edupage.subdomain = subdomain
+
+    def reload_data(self, subdomain: str, session_id: str):
+        request_url = f"https://{subdomain}.edupage.org/user"
+
+        self.edupage.session.cookies.set("PHPSESSID", session_id)
+
+        response = self.edupage.session.get(request_url)
+
+        try:
+            self.__parse_login_data(response.content.decode())
+            self.edupage.subdomain = subdomain
+        except (TypeError, JSONDecodeError) as e:
+            raise BadCredentialsException(f"Invalid session id: {e}")
